var structzypp_1_1JobReport =
[
    [ "EMsgTypeDef", "structzypp_1_1JobReport_1_1EMsgTypeDef.html", "structzypp_1_1JobReport_1_1EMsgTypeDef" ],
    [ "MsgType", "structzypp_1_1JobReport.html#a4c5002826996be6d1ace877fb7308ee7", null ],
    [ "UserData", "structzypp_1_1JobReport.html#aa25cf8999b3974701b405f1154be6e33", null ],
    [ "message", "structzypp_1_1JobReport.html#a8a126305f54a0ccd2c5f22eaa2d87fbd", null ],
    [ "instance", "structzypp_1_1JobReport.html#ae12c6def7dc7e3f50f7f649cdb0f4717", null ],
    [ "debug", "structzypp_1_1JobReport.html#a44c97b15eff55900c6b19d83c176e513", null ],
    [ "info", "structzypp_1_1JobReport.html#afec995def17f5099fe2c0edb3883e4d5", null ],
    [ "warning", "structzypp_1_1JobReport.html#a5832a76ff6d1a7ff7ba3fe26188d261c", null ],
    [ "error", "structzypp_1_1JobReport.html#a67728d8b1932bfd19ecfc1e21458da99", null ],
    [ "important", "structzypp_1_1JobReport.html#ab86b0f359042fed3bbc891a866d1a2b6", null ],
    [ "data", "structzypp_1_1JobReport.html#a943e6e2280fdb59706befb52eab5e010", null ],
    [ "repoRefreshMirrorlist", "structzypp_1_1JobReport.html#ad5d8bd5610c6f20cd5e0e47c4e04f7f0", null ]
];